@@ -10,12 +10,13 @@ import nest_asyncio
 import pandas as pd
 import requests
 from aiohttp import ClientSession
-from functools import partial, partialmethod,cached_property
+from functools import partial, partialmethod
 
 from ClickSQL.conf.parse_rfc_1738_args import parse_rfc1738_args
 from ClickSQL.errors import ParameterKeyError, ParameterTypeError, DatabaseTypeError, DatabaseError, \
     HeartbeatCheckFailure, ClickHouseTableNotExistsError
-from ClickSQL.utils.file_cache import file_cache
+# from ClickSQL.utils.file_cache import file_cache
+from ClickSQL.utils import cached_property, file_cache
 
 """
 this will hold base function of clickhouse and it will apply a path of access clickhouse through clickhouse api service
